@@ -1,10 +1,10 @@
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.1.5)'
+__git_branch__ = '(detached from v0.1.6)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '5061f5dd0ee0fb9d223495a905544b8a0b9d136a'
-__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
+__git_head_hash__ = '2c2402b799549a91260d51aad363618745cdcc68'
+__git_head_subject__ = 'update homepage'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
